@@ -24,9 +24,12 @@
 
 #include "codeine.h"
 #include "timeLabel.h"
+#include "audioView.h"
+#include "loadView.h"
 
 #include <QList>
 #include <QPointer>
+#include <QStackedWidget>
 #include <QCheckBox>
 #include <Phonon/MediaSource>
 #include <KXmlGuiWindow>
@@ -40,9 +43,7 @@ class QMenu;
 class QSlider;
 class QCheckBox;
 
-class FullScreenAction;
-
-namespace Codeine
+namespace Dragon
 {
    class PlayDialog;
    class MainWindow : public KXmlGuiWindow
@@ -59,20 +60,22 @@ namespace Codeine
 
    public:
       void openRecentFile( const KUrl& );
-      bool open( const KUrl& );
       void showVolume( bool );
 
    signals:
-      void dbusStatusChanged( int );
       void fileChanged( QString );
 
    public slots:
+      bool open( const KUrl& );
+      void playDisc();
+      void openFileDialog();
       void play();
-      void playMedia( bool show_welcome_dialog = false );
       void toggleVideoSettings( bool );
       void toggleVolumeSlider( bool );
-      void playDialogResult( int result );
       void restoreDefaultVideoSettings();
+      void toggleLoadView();
+
+
 
    private slots:
       void setFullScreen( bool full );
@@ -84,18 +87,20 @@ namespace Codeine
       void audioChannelsChanged( QList< QAction* > );
       void mutedChanged( bool );
       //in stateChange.cpp
-      void engineStateChanged( Phonon::State );
+      void engineStateChanged( Phonon::State, Phonon::State = Phonon::StoppedState);
       void engineMediaChanged( Phonon::MediaSource );
-      void engineSeekableChanged(bool);
+      void engineSeekableChanged( bool );
       void engineMetaDataChanged();
+      void engineHasVideoChanged( bool );
+
+
 
    private:
-      void playDisc();
+      bool load( const KUrl& );
       void setupActions();
       void updateSliders();
       void updateTitleBarText();
 
-      bool load( const KUrl& );
 
       QMenu *menu( const char *name );
 
@@ -106,6 +111,11 @@ namespace Codeine
 //      virtual void saveProperties( KConfig* );
 //      virtual void readProperties( KConfig* );
 
+      QStackedWidget *m_mainView;
+      AudioView *m_audioView;
+      LoadView *m_loadView;
+      QWidget *m_currentWidget;
+
       QPointer<QDockWidget> m_leftDock;
       QPointer<QDockWidget> m_rightDock;
       QWidget     *m_positionSlider;
@@ -115,7 +125,6 @@ namespace Codeine
       QLabel      *m_titleLabel;
       QList<QSlider*> m_sliders;
       QPointer<PlayDialog> m_playDialog;
-      FullScreenAction *m_fullScreenAction;
 
       KNotificationRestrictions *m_stopScreenSaver;
       int m_stopSleepCookie;
