@@ -1,5 +1,5 @@
 /***********************************************************************
- * Copyright 2008 David Edmundson
+ * Copyright 2008 David Edmundson <kde@davidedmundson.co.uk>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -34,13 +34,17 @@
 RecentlyPlayedList::RecentlyPlayedList(QWidget *parent)
 		:KListWidget(parent)
 {
+  connect(this,SIGNAL(itemDoubleClicked(QListWidgetItem*)),this, SLOT(itemDoubleClicked(QListWidgetItem*)));
   setAlternatingRowColors( true );
   setSelectionMode(QAbstractItemView::SingleSelection);
   
   configGroup = new KConfigGroup( KGlobal::config(), "General" );
-
   loadEntries();
+}
 
+RecentlyPlayedList::~RecentlyPlayedList()
+{
+  delete configGroup;
 }
 
 void
@@ -49,18 +53,6 @@ RecentlyPlayedList::loadEntries()
   clear();
   const QStringList entries = configGroup->readPathEntry( "Recent Urls", QStringList() );
 
-//   foreach( const QString &s, list1 )
-//       urls.prepend(s); //copy the stringlist individually into a KURL list in reverse order
-// 
-//   foreach( const KUrl &it, urls) {
-//       while( urls.count( it ) > 1 )
-//           urls.removeAt( urls.indexOf(it) );
-//       if( it.protocol() == "file" && !QFile::exists( it.path() ) )
-//           //remove stale entries
-//           urls.removeAll( it );
-//     }
-
-  //itterate backwards because the newest entry is at the end
   QListIterator<QString> i(entries);
   i.toBack();
   while(i.hasPrevious())
@@ -82,8 +74,8 @@ RecentlyPlayedList::contextMenuEvent(QContextMenuEvent * event )
 {
   KMenu menu;
   debug() << "Loading Menu";
-  menu.addAction(KIcon("list-remove"),"Remove Entry",this,SLOT(removeEntry()));
-  menu.addAction(KIcon("list-remove"),"Clear List",this,SLOT(clearList()));
+  menu.addAction(KIcon("list-remove"),i18n("Remove Entry"),this,SLOT(removeEntry()));
+  menu.addAction(KIcon("list-remove"),i18n("Clear List"),this,SLOT(clearList()));
   menu.exec( event->globalPos() );
 }
 
@@ -104,4 +96,12 @@ RecentlyPlayedList::clearList()
   loadEntries();
 }
 
+//send the url for the item clicked, not the item
+void
+RecentlyPlayedList::itemDoubleClicked(QListWidgetItem* item)
+{
+  KUrl url = item->data(0xdecade).value<KUrl>();
+  emit(itemDoubleClicked(url));
+}
+
 #include "recentlyPlayedList.moc"
