@@ -37,8 +37,6 @@
 #include "adjustSizeButton.h"
 #include "dbus/playerDbusHandler.h"
 #include "debug.h"
-#include "fullScreenAction.h"
-#include "mxcl.library.h"
 #include "theStream.h"
 #include "videoWindow.h"
 
@@ -51,16 +49,16 @@
 //TODO make convenience function to get fullscreen state
 
 
-namespace Codeine {
+namespace Dragon {
 
 
 void
-MainWindow::engineStateChanged( Phonon::State state )
+MainWindow::engineStateChanged( Phonon::State state, Phonon::State oldstate )
 {
     bool const isFullScreen = toggleAction("fullscreen")->isChecked();
     bool const hasMedia = TheStream::hasMedia();
     QWidget *const toolbar = reinterpret_cast<QWidget*>(toolBar());
-
+    
     switch(state)
     {
       case Phonon::LoadingState:
@@ -101,7 +99,6 @@ MainWindow::engineStateChanged( Phonon::State state )
 
     m_timeLabel->setVisible(enable);
 
-
     debug() << "updated actions";
 
     /// update menus
@@ -182,20 +179,6 @@ MainWindow::engineStateChanged( Phonon::State state )
         case Engine::Loaded:
             break;
         }*/
-    } 
-    switch( state )
-    {
-        case Phonon::StoppedState:
-            emit dbusStatusChanged( PlayerDbusHandler::Stopped ), debug() << "dbus: stopped";
-            break;
-        case Phonon::PausedState:
-            emit dbusStatusChanged( PlayerDbusHandler::Paused ), debug() << "dbus: paused";
-            break;
-        case Phonon::PlayingState:
-            emit dbusStatusChanged( PlayerDbusHandler::Playing ), debug() << "dbus: playing";
-            break;
-        default:/*If none of these states don't emit anything*/
-            break;
     }
 }//engineStateChanged
 
@@ -203,6 +186,8 @@ MainWindow::engineStateChanged( Phonon::State state )
 void
 MainWindow::engineMediaChanged(Phonon::MediaSource /*newSource*/)
 {
+    m_audioView->updateText();
+
     // update recently played list
     debug() << " update recent files list ";
 
@@ -238,6 +223,24 @@ void MainWindow::engineMetaDataChanged()
 {
     debug() << "metaDataChanged";
     updateTitleBarText();
+    m_audioView->updateText();
+}
+
+void MainWindow::engineHasVideoChanged(bool hasVideo)
+{
+  debug() << "hasVideo changed";
+  if( TheStream::hasVideo() )
+  {
+    if( m_mainView->indexOf(engine()) == -1 )
+      m_mainView->addWidget(engine());
+    m_mainView->setCurrentWidget(engine());
+    m_currentWidget = engine();
+  }
+  else
+  {
+    m_mainView->setCurrentWidget(m_audioView);
+    m_currentWidget = m_audioView;
+  }
 }
 
 }//namespace
