@@ -13,17 +13,21 @@
  *                                                                         *
  ***************************************************************************/
 
+#include "exampleoptions.h"
+
+#include <QHideEvent>
+#include <QShowEvent>
+#include <QVBoxLayout>
+
 #include <kurlrequester.h>
 #include <klocale.h>
 
-#include <qradiobutton.h>
-#include <qlayout.h>
-
-#include "exampleoptions.h"
-
 ExampleOptions::ExampleOptions(QWidget *parent) :
-    ExampleOptionsBase(parent, "example options widget")
+    QWidget(parent)
 {
+    setupUi(this);
+
+    setObjectName("example options widget");
 }
 
 void ExampleOptions::exampleSelectionChanged()
@@ -45,24 +49,31 @@ void ExampleOptions::exampleFileChanged()
 }
 
 ExampleOptionsDialog::ExampleOptionsDialog(QWidget *parent) :
-    QDialog(parent, "example options dialog")
+    QDialog(parent)
 {
-    setCaption(i18n("JuK"));
+    setObjectName("example options dialog");
+    setWindowTitle(i18n("JuK"));
     QVBoxLayout *l = new QVBoxLayout(this);
 
     m_options = new ExampleOptions(this);
+    m_options->m_exampleFile->setMode(KFile::ExistingOnly|KFile::LocalOnly);
     l->addWidget(m_options);
 
     // Forward signals
 
     connect(m_options, SIGNAL(fileChanged()), SLOT(fileModeSelected()));
     connect(m_options, SIGNAL(dataChanged()), SIGNAL(dataChanged()));
-    connect(m_options->m_exampleFile, SIGNAL(urlSelected(const QString &)),
-            this,                     SIGNAL(fileChanged(const QString &)));
+    connect(m_options->m_exampleFile, SIGNAL(urlSelected(const KUrl &)),
+            this,                     SLOT(fileChanged(const KUrl &)));
     connect(m_options->m_exampleFile, SIGNAL(returnPressed(const QString &)),
             this,                     SIGNAL(fileChanged(const QString &)));
 }
 
+void ExampleOptionsDialog::fileChanged(const KUrl &url)
+{
+    emit fileChanged(url.path());
+}
+
 void ExampleOptionsDialog::hideEvent(QHideEvent *)
 {
     emit signalHidden();
@@ -80,4 +91,4 @@ void ExampleOptionsDialog::fileModeSelected()
 
 #include "exampleoptions.moc"
 
-// vim: set et sw=4 ts=4:
+// vim: set et sw=4 tw=0 sta:
