@@ -55,7 +55,7 @@
 #include <QDropEvent>
 #include <QDragEnterEvent>
 #include <QPixmap>
-#include <Q3WidgetStack>
+#include <QStackedWidget>
 #include <id3v1genres.h>
 
 #include <time.h>
@@ -579,29 +579,28 @@ void Playlist::saveAs()
     }
 }
 
-void Playlist::clearItem(PlaylistItem *item, bool emitChanged)
+void Playlist::updateDeletedItem(PlaylistItem *item)
 {
-    emit signalAboutToRemove(item);
     m_members.remove(item->file().absFilePath());
     m_search.clearItem(item);
 
     m_history.removeAll(item);
     m_addTime.removeAll(item);
     m_subtractTime.removeAll(item);
+}
 
+void Playlist::clearItem(PlaylistItem *item, bool emitChanged)
+{
+    // Automatically updates internal structs via updateDeletedItem
     delete item;
-    if(emitChanged)
-        dataChanged();
+
+    dataChanged();
 }
 
 void Playlist::clearItems(const PlaylistItemList &items)
 {
-    m_blockDataChanged = true;
-
-    for(PlaylistItemList::ConstIterator it = items.constBegin(); it != items.constEnd(); ++it)
-        clearItem(*it, false);
-
-    m_blockDataChanged = false;
+    foreach(PlaylistItem *item, items)
+        delete item;
 
     dataChanged();
 }
@@ -776,7 +775,7 @@ void Playlist::slotRefresh()
             kDebug(65432) << "Error while trying to refresh the tag.  "
                            << "This file has probably been removed."
                            << endl;
-            clearItem((*it)->collectionItem());
+            delete (*it)->collectionItem();
         }
 
         processEvents();
@@ -850,6 +849,9 @@ void Playlist::slotAddCover(bool retrieveLocal)
     KUrl file = KFileDialog::getImageOpenUrl(
         KUrl( "kfiledialog://homedir" ), this, i18n("Select Cover Image File"));
 
+    if(file.isEmpty())
+        return;
+
     QString artist = items.front()->file().tag()->artist();
     QString album = items.front()->file().tag()->album();
 
@@ -985,7 +987,7 @@ void Playlist::removeFromDisk(const PlaylistItemList &items)
                 if((!shouldDelete && KIO::NetAccess::synchronousRun(KIO::trash(removePath), this)) ||
                    (shouldDelete && QFile::remove(removePath)))
                 {
-                    CollectionList::instance()->clearItem((*it)->collectionItem());
+                    delete (*it)->collectionItem();
                 }
                 else
                     errorFiles.append((*it)->file().absFilePath());
