@@ -47,6 +47,10 @@
 #define ALSA_MIXER
 #endif
 
+#ifdef HAVE_PULSE
+#define PULSE_MIXER
+#endif
+
 #define OSS_MIXER
 #endif
 
@@ -77,6 +81,11 @@
 #include "mixer_alsa9.cpp"
 #endif
 
+// Pulse API
+#if defined(PULSE_MIXER)
+#include "mixer_pulse.cpp"
+#endif
+
 #if defined(OSS_MIXER)
 #include "mixer_oss.cpp"
 #endif
@@ -116,6 +125,10 @@ MixerFactory g_mixerFactories[] = {
     { HPUX_getMixer, HPUX_getDriverName },
 #endif
 
+#if defined(PULSE_MIXER)
+    { PULSE_getMixer, PULSE_getDriverName },
+#endif
+
     { 0, 0 }
 };
 
